@@ -221,6 +221,8 @@ class Session(object):
                 raise accsynException("Please supply your accsyn API KEY or set ACCSYN_API_KEY " "environment!")
         self._hostname = hostname
         self._port = port or ACCSYN_PORT
+        self._timeout = timeout or Session.DEFAULT_TIMEOUT
+        self._connect_timeout = connect_timeout or Session.DEFAULT_CONNECT_TIMEOUT
         if self._hostname is None:
             if self._dev:
                 self._hostname = "172.16.178.161"
@@ -239,8 +241,6 @@ class Session(object):
                     ACCSYN_CLOUD_DOMAIN,
                 )
         self._last_message = None
-        self._timeout = timeout or Session.DEFAULT_TIMEOUT
-        self._connect_timeout = connect_timeout or Session.DEFAULT_CONNECT_TIMEOUT
         self.login()
 
     @staticmethod
@@ -586,8 +586,7 @@ class Session(object):
         :param entitytype: The type of entity to update (job, share, acl, ..)
         :param entityid: The id of the entity.
         :param data: The dictionary containing attributes to update.
-        :return: The updated entity data, as dictionary.
-        """
+        :return: The updated entity data, as dictionary
 
         .. deprecated:: 2.0.2
             Since Python 2.0.2 you should use the :func:`update` function instead
@@ -807,6 +806,8 @@ class Session(object):
         getsize=False,
         files_only=False,
         directories_only=False,
+        include=None,
+        exclude=None,
     ):
         """
         List files on a share.
@@ -817,7 +818,15 @@ class Session(object):
         :param getsize: If True - file sizes will be returned.
         :param files_only: If True - only return files, no directories.
         :param directories_only: If True - only return directories, no files.
+        :param include: Filter expression (string or list) dictating what to include in result: "word" - exact match, "*word" - ends with word, "word*" - starts with word, "*word*" - contains word, "start*end" - starts & ends with word and "re('...')" - regular expression. Has precedence over *exclude*.
+        :param exclude: Filter expression (string or list) dictating what to exclude from result: "word" - exact match, "*word" - ends with word, "word*" - starts with word, "*word*" - contains word, "start*end" - starts & ends with word and "re('...')" - regular expression.
         :return: A dictionary containing result of file listing.
+
+        Include and exclude filters are case-insensitive, to make regular expression case-sensitive, use the following
+        syntax: "re('...', 'I')".
+
+        .. versionadded:: 2.2.0 (app/daemon: 2.6-20)
+
         """
         assert 0 < len(path or "") and (
             Session._is_str(path) or isinstance(path, dict) or isinstance(path, list)
@@ -835,16 +844,27 @@ class Session(object):
             data["directories_only"] = directories_only
         if files_only:
             data["files_only"] = files_only
+        if include:
+            data["include"] = include
+        if exclude:
+            data["exclude"] = exclude
         response = self._event("GET", "organization/file", data)
         if response:
             return response["result"]
 
-    def getsize(self, path):
+    def getsize(self, path, include=None, exclude=None):
         """
         Get size of a file or directory.
 
         :param path: The accsyn path, on the form 'share=<the share>/<path>/<somewhere>'.
-        :return: A number representing the file size.
+        :param include: Filter expression (string or list) dictating what to include in result: "word" - exact match, "*word" - ends with word, "word*" - starts with word, "*word*" - contains word, "start*end" - starts & ends with word and "re('...')" - regular expression. Has precedence over *exclude*.
+        :param exclude: Filter expression (string or list) dictating what to exclude from result: "word" - exact match, "*word" - ends with word, "word*" - starts with word, "*word*" - contains word, "start*end" - starts & ends with word and "re('...')" - regular expression.
+        :return: A dictionary containing result of file listing.
+
+        Include and exclude filters are case-insensitive, to make regular expression case-sensitive, use the following
+        syntax: "re('...', 'I')".
+
+        .. versionadded:: 2.2.0 (app/daemon: 2.6-20)
         """
         assert 0 < len(path or "") and (
             Session._is_str(path) or isinstance(path, dict) or isinstance(path, list)
@@ -853,6 +873,10 @@ class Session(object):
             "op": "getsize",
             "path": path,
         }
+        if include:
+            data["include"] = include
+        if exclude:
+            data["exclude"] = exclude
         response = self._event("GET", "organization/file", data)
         if response:
             return response["result"]
@@ -1317,7 +1341,7 @@ class Session(object):
                     )
                 do_retry = False
                 if not retval.get("message") is None:
-                    # Some thing went wrong
+                    # Something went wrong
                     if retval.get("session_expired") is True:
                         if self._api_key is not None:
                             # We should be able to get a new session and retry
